@REM All Rights Reserved - Licensed Materials - Property of IBM
@REM 5724-J08, 5724-I63, 5724-H88, 5724-H89, 5655-N02, 5733-W70 COPYRIGHT International Business Machines Corp., 2009
@REM US Government Users Restricted Rights - Use, duplication or disclosure
@REM restricted by GSA ADP Schedule Contract with IBM Corp.

@echo off

rem setupCEA.bat

rem Use setupCEA.bat and setupCEA.py to create and customize an IBM
rem WebSphere Application Server profile suitable for evaluating the
rem Feature Pack for Communications Enabled Applications (CEA).

rem setupCEA.bat does the following:
rem -Creates a CEA-compatible standalone application server profile
rem -Generates EJB deployment bindings in PlantsByWebSphereAjax for CEA
rem -Starts the application server
rem -Runs setupCEA.py, a wsadmin script that does the following:
rem   -Enables the CEA communications service
rem   -Installs the sample IP-PBX application
rem   -Defines the JDBC provider for PlantsByWebSphereAjax for CEA
rem   -Defines the data source for PlantsByWebSphereAjax for CEA
rem   -Installs PlantsByWebSphereAjax for CEA
rem   -Installs the Web service sample application
rem   -Starts the sample IP-PBX application
rem   -Starts PlantsByWebSphereAjax for CEA
rem   -Starts the Web service sample application
rem -Restarts the application server

rem Procedure
rem 1. Install IBM WebSphere Application Server Version 7.0, required fixes,
rem    and the CEA Feature Pack. For further information, see the formal
rem    product documentation at
rem    http://www.ibm.com/software/webservers/appserv/was/library/
rem 2. Place this file (setupCEA.bat) and setupCEA.py in the WebSphere
rem    Application Server bin directory, e.g.,
rem    C:\Program Files\IBM\WebSphere\AppServer\bin
rem 3. Customize the three path variables below, and if desired, the
rem    profileName, cellName, nodeName, and serverName variables.
rem 4. Run this file (setupCEA.bat).

set wasPath=C:\Program Files\IBM\WebSphere\AppServer
set profilePath=C:\Program Files\IBM\WebSphere\AppServer\Profiles\AppSrvCEA
set tempPath=C:\temp
set profileName=AppSrvCEA
set cellName=AppSrvCEACell01
set nodeName=AppSrvCEANode01
set serverName=server1

echo.
echo Creating profile %profileName%
call "%wasPath%\bin\manageprofiles" -create -profileName "%profileName%" -profilePath "%profilePath%" -templatePath "%wasPath%\profileTemplates\CEA\default.ceafep" -nodeName "%nodeName%" -cellName "%cellName%" -hostName localhost -enableAdminSecurity false -isDefault false -winserviceCheck false

echo.
echo Generating EJB deployment bindings in CEA PlantsByWebSphereAjax sample
set plantsAppUndeployedPath=%wasPath:\=/%/feature_packs/cea/samples/plantsbywebsphere/PlantsByWebSphere.ear
set plantsAppPath=%wasPath:\=/%/feature_packs/cea/samples/plantsbywebsphere/PlantsByWebSphere_Deployed.ear
call "%wasPath%\bin\ejbdeploy" "%plantsAppUndeployedPath%" "%tempPath%" "%plantsAppPath%" -dbvendor DERBY_V10

echo.
echo Starting the server
call "%profilePath%\bin\startServer" "%serverName%"

echo.
echo Running wsadmin script setupCEA.py
set pbxAppPath=%wasPath:\=/%/feature_packs/cea/samples/commsvc.pbx.ear
set wsAppPath=%wasPath:\=/%/feature_packs/cea/samples/webservice.sample/commsvc.ws.sample.ear
call "%profilePath%\bin\wsadmin" -lang jython -f "%wasPath%\bin\setupCEA.py" "%pbxAppPath%" "%plantsAppPath%" "%wsAppPath%" "%cellName%" "%nodeName%" "%serverName%"

echo.
echo Restarting the server
call "%profilePath%\bin\stopServer" "%serverName%"
call "%profilePath%\bin\startServer" "%serverName%"
