# Licensed Material - Property of IBM 
# 5724-J08, 5724-I63, 5724-H88, 5724-H89, 5655-N02, 5733-W70 Copyright IBM Corp. 2009 - All Rights Reserved. 
# US Government Users Restricted Rights - Use, duplication or disclosure 
# restricted by GSA ADP Schedule Contract with IBM Corp. 

# setupCEA.py

import sys
import time

if(len(sys.argv) != 6):
  print "Usage: wsadmin -lang jython -f setupCEA_Apps.py <pbx_app_path> <plants_app_path> <ws_app_path> <cell_name> <node_name> <server_name>"
  sys.exit()

pbxAppPath = sys.argv[0]
plantsAppPath = sys.argv[1]
wsAppPath = sys.argv[2]
cellName = sys.argv[3]
nodeName = sys.argv[4]
serverName = sys.argv[5]

print " "
print "Enabling CEA Communication Service (system application)"
deployment = AdminConfig.getid("/Deployment:commsvc/")
deployedObject = AdminConfig.showAttribute(deployment, 'deployedObject')
rawTargetMappings = AdminConfig.showAttribute(deployedObject, 'targetMappings')
# Convert string list to list
targetMappingList = rawTargetMappings[1:(len(rawTargetMappings) - 1)]
targetMappingList = targetMappingList.split()
for targetMapping in targetMappingList:
  # Enable application if the target is a server on node nodeName with name serverName
  currentTarget = AdminConfig.showAttribute(targetMapping, 'target')
  if (currentTarget.find("ServerTarget") > 0):
    if ((AdminConfig.showAttribute(currentTarget, 'nodeName') == nodeName) & (AdminConfig.showAttribute(currentTarget, 'name') == serverName)):
      AdminConfig.modify(targetMapping, '[[enable "true"]]')

print " "
print "Installing the sample IP-PBX application"
AdminApp.install(pbxAppPath, '[-nopreCompileJSPs -distributeApp -nouseMetaDataFromBinary -nodeployejb -appname commsvc.pbx -createMBeansForResources -noreloadEnabled -nodeployws -validateinstall warn -noprocessEmbeddedConfig -filepermission .*\.dll=755#.*\.so=755#.*\.a=755#.*\.sl=755 -noallowDispatchRemoteInclude -noallowServiceRemoteInclude -asyncRequestDispatchType DISABLED -nouseAutoLink -MapModulesToServers [[CSTASipPbx commsvc.pbx.war,WEB-INF/sip.xml WebSphere:cell=' + cellName + ',node=' + nodeName + ',server=' + serverName + ' ]]]')

print " "
print "Defining the JDBC provider for the CEA PlantsByWebSphereAjax sample application"
jdbcProvider = AdminTask.createJDBCProvider('[-scope Node=' + nodeName + ',Server=' + serverName + ' -databaseType Derby -providerType "Derby JDBC Provider" -implementationType "XA data source" -name "Derby JDBC Provider for PlantsByWebSphereAjax (XA)" -description "Derby embedded XA JDBC Provider. This provider is only configurable in version 6.0.2 and later nodes" -classpath [${DERBY_JDBC_DRIVER_PATH}/derby.jar ] -nativePath "" ]')

print " "
print "Defining the data source for the CEA PlantsByWebSphereAjax sample application"
AdminTask.createDatasource(jdbcProvider, '[-name PLANTSDB -jndiName jdbc/PlantsByWebSphereAjaxDataSource -dataStoreHelperClassName com.ibm.websphere.rsadapter.DerbyDataStoreHelper -containerManagedPersistence true -componentManagedAuthenticationAlias -xaRecoveryAuthAlias -configureResourceProperties [[databaseName java.lang.String "${APP_INSTALL_ROOT}/${CELL}/PlantsByWebSphereAjax.ear/Database/PLANTSDB"]]]')

print " "
print "Installing the CEA PlantsByWebSphereAjax sample application"
AdminApp.install(plantsAppPath, '[ -nopreCompileJSPs -distributeApp -nouseMetaDataFromBinary -nodeployejb -appname PlantsByWebSphereAjax -createMBeansForResources -noreloadEnabled -nodeployws -validateinstall warn -noprocessEmbeddedConfig -filepermission .*\.dll=755#.*\.so=755#.*\.a=755#.*\.sl=755 -noallowDispatchRemoteInclude -noallowServiceRemoteInclude -asyncRequestDispatchType DISABLED -nouseAutoLink -MapModulesToServers [[ "PlantsByWebSphere EJB Module" PlantsByWebSphereAjax_EJB.jar,META-INF/ejb-jar.xml WebSphere:cell=' + cellName + ',node=' + nodeName + ',server=' + serverName + ' ][ "PlantsByWebSphere Web Application" PlantsByWebSphere.war,WEB-INF/web.xml WebSphere:cell=' + cellName + ',node=' + nodeName + ',server=' + serverName + ' ]]]' )

print " "
print "Installing the CEA Web service sample application"
AdminApp.install(wsAppPath, '[ -nopreCompileJSPs -distributeApp -nouseMetaDataFromBinary -nodeployejb -appname commsvc.ws.sample -createMBeansForResources -noreloadEnabled -nodeployws -validateinstall warn -noprocessEmbeddedConfig -filepermission .*\.dll=755#.*\.so=755#.*\.a=755#.*\.sl=755 -noallowDispatchRemoteInclude -noallowServiceRemoteInclude -asyncRequestDispatchType DISABLED -nouseAutoLink -MapModulesToServers [[ commsvc.ws.sample commsvc.ws.sample.war,WEB-INF/web.xml WebSphere:cell=' + cellName + ',node=' + nodeName + ',server=' + serverName + ' ]]]' )

print " "
print "Saving changes"
AdminConfig.save()

print " "
print "Starting the Sample IP-PBX application"
appManager = AdminControl.queryNames('cell=' + cellName + ',node=' + nodeName + ',type=ApplicationManager,process=' + serverName + ',*')
AdminControl.invoke(appManager, 'startApplication', 'commsvc.pbx')

print " "
print "Starting the CEA PlantsByWebSphereAjax sample application"
AdminControl.invoke(appManager, 'startApplication', 'PlantsByWebSphereAjax')

print " "
print "Starting the CEA Web service sample application"
AdminControl.invoke(appManager, 'startApplication', 'commsvc.ws.sample')
