# All Rights Reserved - Licensed Materials - Property of IBM
# 5724-J08, 5724-I63, 5724-H88, 5724-H89, 5655-N02, 5733-W70 COPYRIGHT International Business Machines Corp., 2009
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.


# SetupCEA.sh

# Use setupCEA.sh and setupCEA.py to create and customize an IBM
# WebSphere Application Server profile suitable for evaluating the
# Feature Pack for Communications Enabled Applications (CEA).

# setupCEA.sh does the following:
# -Creates a CEA-compatible standalone application server profile
# -Generates EJB deployment bindings in PlantsByWebSphereAjax for CEA
# -Starts the application server
# -Runs setupCEA.py, a wsadmin script that does the following:
#   -Enables the CEA communications service
#   -Installs the sample IP-PBX application
#   -Defines the JDBC provider for PlantsByWebSphereAjax for CEA
#   -Defines the data source for PlantsByWebSphereAjax for CEA
#   -Installs PlantsByWebSphereAjax for CEA
#   -Installs the Web service sample application
#   -Starts the sample IP-PBX application
#   -Starts PlantsByWebSphereAjax for CEA
#   -Starts the Web service sample application
# -Restarts the application server

# Procedure
# 1. Install IBM WebSphere Application Server Version 7.0, required fixes,
#    and the CEA Feature Pack. For further information, see the formal
#    product documentation at
#    http://www.ibm.com/software/webservers/appserv/was/library/
# 2. Place this file (setupCEA.sh) and setupCEA.py in the WebSphere
#    Application Server bin directory, e.g., /opt/IBM/WebSphere/AppServer/bin
# 3. Customize the three path variables below, and if desired, the
#    profileName, cellName, nodeName, and serverName variables.
# 4. Run this file (setupCEA.sh).

wasPath=/opt/IBM/WebSphere/AppServer
profilePath=/opt/IBM/WebSphere/AppServer/profiles/AppSrvCEA
tmpPath=/tmp
profileName=AppSrvCEA
cellName=AppSrvCEACell01
nodeName=AppSrvCEANode01
serverName=server1

echo " "
echo "Creating profile $profileName"
$wasPath/bin/manageprofiles.sh -create -profileName $profileName -profilePath $profilePath -templatePath $wasPath/profileTemplates/CEA/default.ceafep -nodeName $nodeName -cellName $cellName -hostName localhost -enableAdminSecurity false -isDefault false

echo " "
echo "Generating EJB deployment bindings in CEA PlantsByWebSphereAjax sample"
plantsAppUndeployedPath=$wasPath/feature_packs/cea/samples/plantsbywebsphere/PlantsByWebSphere.ear
plantsAppPath=$wasPath/feature_packs/cea/samples/plantsbywebsphere/PlantsByWebSphere_Deployed.ear
$wasPath/bin/ejbdeploy.sh $plantsAppUndeployedPath $tmpPath $plantsAppPath -dbvendor DERBY_V10

echo " "
echo "Starting the server"
$profilePath/bin/startServer.sh $serverName

echo " "
echo "Running wsadmin script setupCEA.py"
pbxAppPath=$wasPath/feature_packs/cea/samples/commsvc.pbx.ear
wsAppPath=$wasPath/feature_packs/cea/samples/webservice.sample/commsvc.ws.sample.ear
$profilePath/bin/wsadmin.sh -lang jython -f $wasPath/bin/setupCEA.py $pbxAppPath $plantsAppPath $wsAppPath $cellName $nodeName $serverName

echo " "
echo "Restarting the server"
$profilePath/bin/stopServer.sh $serverName
$profilePath/bin/startServer.sh $serverName
